tablecloth.time.utils.datatypes


get-datatypeclj

(get-datatype col-or-val)

Get the unpacked datatype of a column.

This is typically what you want when checking temporal types, as packed datatypes include storage metadata that obscures the semantic type.

Get the unpacked datatype of a column.

This is typically what you want when checking temporal types, as packed
datatypes include storage metadata that obscures the semantic type.
sourceraw docstring

temporal-type?clj

(temporal-type? dtype)
source

cljdoc builds & hosts documentation for Clojure/Script libraries