tablecloth.time.utils.units


calendar-unit?clj

(calendar-unit? u)

Check if unit is a calendar/variable-duration unit.

Check if unit is a calendar/variable-duration unit.
sourceraw docstring

metric-unit?clj

(metric-unit? u)

Check if unit is a metric/fixed-duration unit.

Check if unit is a metric/fixed-duration unit.
sourceraw docstring

milliseconds-inclj

(milliseconds-in unit)

Return the number of epoch millis in a unit.

Units: :milliseconds :seconds :minutes :hours :days :weeks.

Return the number of epoch millis in a unit.

Units: :milliseconds :seconds :minutes :hours :days :weeks.
sourceraw docstring

normalize-unitclj

(normalize-unit u)

Normalize a unit across plural or singular usages. Plural is the normalized version. Noop if type is not supported.

Normalize a unit across plural or singular usages. Plural is the
normalized version. Noop if type is not supported.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries