(get-datatype col-or-val)Get the unpacked datatype of a column.
This is typically what you want when checking temporal types, as packed datatypes include storage metadata that obscures the semantic type.
Get the unpacked datatype of a column. This is typically what you want when checking temporal types, as packed datatypes include storage metadata that obscures the semantic type.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |