(calendar-local-type? dtype)Returns true if dtype is a calendar-local type (lacks time zone information).
Returns true if dtype is a calendar-local type (lacks time zone information).
(coerce-zone-id z)(coerce-zone-id z opts)Coerce nil/String/ZoneId to a ZoneId.
Coerce nil/String/ZoneId to a ZoneId. - 1-arg arity: nil -> system zone. - 2-arg arity: nil -> (:default opts).
(normalize-target t)Normalize a target designator (keyword or Class) to a canonical keyword in targets.
TODO: Right now dtype-next's object-class->datatype return :object for unsupported types bypassing our error messaging. Need to decide if this is good.
Normalize a target designator (keyword or Class) to a canonical keyword in `targets`. TODO: Right now dtype-next's object-class->datatype return :object for unsupported types bypassing our error messaging. Need to decide if this is good.
Map of shorthand type aliases to canonical type keywords.
Map of shorthand type aliases to canonical type keywords.
Set of valid temporal target types for conversion.
Set of valid temporal target types for conversion.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |