(calendar-unit? u)Check if unit is a calendar/variable-duration unit.
Check if unit is a calendar/variable-duration unit.
(metric-unit? u)Check if unit is a metric/fixed-duration unit.
Check if unit is a metric/fixed-duration unit.
(milliseconds-in unit)Return the number of epoch millis in a unit.
Units: :milliseconds :seconds :minutes :hours :days :weeks.
Return the number of epoch millis in a unit. Units: :milliseconds :seconds :minutes :hours :days :weeks.
(normalize-unit u)Normalize a unit across plural or singular usages. Plural is the normalized version. Noop if type is not supported.
Normalize a unit across plural or singular usages. Plural is the normalized version. Noop if type is not supported.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |